@@ -5,7 +5,7 @@ use Dwarf::Message;
 use Dwarf::Request;
 use Dwarf::Response;
 use Dwarf::Trigger;
-use Dwarf::Util qw/capitalize read_file filename load_class dwarf_log/;
+use Dwarf::Util qw/capitalize read_file filename installed load_class dwarf_log/;
 use Cwd 'abs_path';
 use Data::Dumper;
 use File::Basename 'dirname';
@@ -14,7 +14,7 @@ use Module::Find;
 use Router::Simple;
 use Scalar::Util qw/weaken/;
 
-our $VERSION = '1.30';
+our $VERSION = '1.31';
 
 use constant {
 	BEFORE_DISPATCH    => 'before_dispatch',
@@ -245,6 +245,9 @@ sub finalize {
 	# プロセス名を idle にする
 	$self->proctitle(sprintf "[Dwarf] idle (%s)", $self->base_dir);
 
+	# ストリーミング用
+	return $self->body if ref $self->body eq 'CODE';
+
 	my $res = $self->response->finalize;
 	return $res;
 }
@@ -429,6 +432,7 @@ sub proctitle {
 
 	if ($^O eq 'linux' and load_class("Sys::Proctitle")) {
 		Sys::Proctitle::setproctitle($title);
+		no warnings 'redefine';
 		*proctitle = sub { Sys::Proctitle::setproctitle($title) };
 		return;
 	}
@@ -460,7 +464,11 @@ sub load_plugins {
 
 sub load_plugin {
 	my ($class, $module, $conf) = @_;
-	$module = load_class($module, 'Dwarf::Plugin');
+	if (installed($module, 'App::Plugin')) {
+		$module = load_class($module, 'App::Plugin');
+	} else {
+		$module = load_class($module, 'Dwarf::Plugin');
+	}
 	$module->init($class, $conf);
 }
 
